/*********
*
* This file is part of BibleTime's source code, http://www.bibletime.info/.
*
* Copyright 1999-2008 by the BibleTime developers.
* The BibleTime source code is licensed under the GNU General Public License version 2.0.
*
**********/

#include "btconfig.h"

#include <QString>
#include <QVariant>


BtConfig::BtConfig()
{
	init();
}

BtConfig::~BtConfig()
{}

void BtConfig::set(QString key, QVariant value)
{
	Q_ASSERT(m_defaultMap.contains(key));

	ConfigStruct cs = m_defaultMap[key];
	Q_ASSERT(cs.type = value.type());

	switch(cs.flag) {
	case Save:
		if (value != cs.defaultValue) {
			m_settings.setValue(key, value);
		}
		break;
	case NoSave:
		m_nonSaveSettings.insert(key, value);
		break;
	case ReadOnly:
		break;
	}

}

QVariant BtConfig::get(QString key)
{
	Q_ASSERT(m_defaultMap.contains(key));
	ConfigStruct cs = m_defaultMap[key];
	switch(cs.flag) {
	case ReadOnly:
		return cs.defaultValue;
		break;
	case NoSave:
		if (m_nonSaveSettings.contains(key)) {
			return m_nonSaveSettings[key];
		} else {
			return cs.defaultValue;
		}
		break;
	case Save:
		if (m_settings.contains(key)) {
			return m_settings.value(key);
		} else {
			return cs.defaultValue;
		}
		break;
	}
	return QVariant();
}

QVariant BtConfig::getDefault(QString key)
{
	Q_ASSERT(m_defaultMap.contains(key));
	return m_defaultMap[key].defaultValue;
}

void BtConfig::add(QString key, QVariant defaultValue, ConfigFlag flag, QVariant::Type type)
{
	Q_ASSERT(defaultValue.type() == type);

	ConfigStruct configStruct = {defaultValue, flag, type};
	m_defaultMap.insert(key, configStruct);
}
